<p align="left"><img src="docs/_static/ForMoSA.png" alt="ForMoSA" width="250"/></p>


Welcome to ForMoSA, an open-source Python package. 

We designed this tool to model exoplanetary atmospheres with a forward modeling approach. 
We encourage you to exploit its capabilities!

Get started at [https://formosa.readthedocs.io](https://formosa.readthedocs.io)

***
 
[![PyPI version](https://badge.fury.io/py/formosa.svg)](https://badge.fury.io/py/formosa)
[![PyPI downloads](https://img.shields.io/pypi/dm/formosa.svg)](https://pypistats.org/packages/formosa)
[![Documentation Status](https://readthedocs.org/projects/formosa/badge/?version=latest)](https://formosa.readthedocs.io/en/latest/?badge=latest)
[![License](https://img.shields.io/badge/License-BSD%203--Clause-blue.svg)](https://opensource.org/licenses/BSD-3-Clause)
[![A rectangular badge, half black half purple containing the text made at Code Astro](https://img.shields.io/badge/Made%20at-Code/Astro-blueviolet.svg)](https://semaphorep.github.io/codeastro/)

